Python Client for Inbus 
=======================

.. image:: https://travis-ci.org/mlos/inbus.client.python.svg?branch=master
   :target: https://travis-ci.org/mlos/inbus.client.python

Python client for `Inbus <https://github.com/mlos/inbus>`

